using Nirvana.Common;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Waste.Domain;

namespace Waste.Application
{
    /// <summary>
    /// 苏州设备接入平台管理
    /// </summary>
    public interface ISZPltService
    {
        /// <summary>
        /// 获取地产区域列表
        /// </summary>
        /// <param name="param"></param>
        /// <returns></returns>
        Task<PageParms<W_SZAddress>> GetAddressListAsync(QueryParams param);
        /// <summary>
        /// 获取地产区域所有列表
        /// </summary>
        /// <returns></returns>
        Task<List<W_SZAddress>> GetAddressAllListAsync();
        /// <summary>
        /// 地产区域信息提交
        /// </summary>
        /// <param name="data"></param>
        /// <returns></returns>
        Task<ResultInfo> SubmitAddressFormAsync(W_SZAddress data);
        /// <summary>
        /// 地产区域详情
        /// </summary>
        /// <param name="id"></param>
        /// <returns></returns>
        Task<W_SZAddress> DetailAddressAsync(Guid id);
        /// <summary>
        /// 删除地产区域
        /// </summary>
        /// <param name="id"></param>
        /// <returns></returns>
        Task<ResultInfo> DeleteAddressAsync(Guid id);

        /// <summary>
        /// 获取采集点列表
        /// </summary>
        /// <param name="param"></param>
        /// <returns></returns>
        Task<PageParms<SZCollectList>> GetCollectListAsync(QueryParams param);

        /// <summary>
        /// 采集点信息提交
        /// </summary>
        /// <param name="data"></param>
        /// <returns></returns>
        Task<ResultInfo> SubmitCollectFormAsync(W_SZCollect data);

        /// <summary>
        /// 采集点详情
        /// </summary>
        /// <param name="id"></param>
        /// <returns></returns>
        Task<W_SZCollect> DetailCollectAsync(Guid id);
        /// <summary>
        /// 删除采集点
        /// </summary>
        /// <param name="id"></param>
        /// <returns></returns>
        Task<ResultInfo> DeleteCollectAsync(Guid id);
    }
}
